==> libgnomeui-1.108.0.tar.bz2: libgnomeui-1.108.0/libgnomeui/libgnomeui.h <==
/*  -*- Mode: C; c-set-style: linux; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
/*
 * Copyright (C) 1997, 1998, 1999, 2000 Free Software Foundation
 * All rights reserved.
 *
 * This file is part of the Gnome Library.
 *
 * The Gnome Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * The Gnome Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with the Gnome Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
/*
  @NOTATION@
 */

#ifndef LIBGNOMEUI_H
#define LIBGNOMEUI_H


#include <libgnomeui/gnome-uidefs.h>

#include <libgnomeui/gnome-about.h>
#include <libgnomeui/gnome-app.h>
#include <libgnomeui/gnome-app-helper.h>
#include <libgnomeui/gnome-app-util.h>
#include <libgnomeui/gnome-appbar.h>
#include <libgnomecanvas/gnome-canvas.h>
#include <libgnomecanvas/gnome-canvas-pixbuf.h>
#include <libgnomecanvas/gnome-canvas-line.h>
#include <libgnomecanvas/gnome-canvas-rect-ellipse.h>
#include <libgnomecanvas/gnome-canvas-polygon.h>
#include <libgnomecanvas/gnome-canvas-text.h>
#include <libgnomecanvas/gnome-canvas-util.h>
#include <libgnomecanvas/gnome-canvas-widget.h>
#include <libgnomeui/gnome-color-picker.h>
#include <libgnomeui/gnome-entry.h>
#include <libgnomeui/gnome-file-entry.h>
#include <libgnomeui/gnome-font-picker.h>
#include <libgnomeui/gnome-icon-entry.h>
#include <libgnomeui/gnome-icon-list.h>
#include <libgnomeui/gnome-icon-sel.h>
#include <libgnomeui/gnome-ui-init.h>
#include <libgnomeui/gnome-types.h>
#include <libgnomeui/gnome-stock-icons.h>
#include <libgnomeui/gnome-scores.h>
#include <libgnomeui/gnome-client.h>
#include <libgnomeui/gnome-dateedit.h>
#include <libgnomeui/gnometypebuiltins.h>
#include <libgnomeui/gnome-href.h>
#include <libgnomeui/gnome-dialog.h>
#include <libgnomeui/gnome-dialog-util.h>
#include <libgnomeui/gnome-druid.h>
#include <libgnomeui/gnome-druid-page.h>
#include <libgnomeui/gnome-druid-page-edge.h>
#include <libgnomeui/gnome-druid-page-standard.h>
#include <libgnomeui/gnome-messagebox.h>
#include <libgnomeui/gnome-mdi.h>
#include <libgnomeui/gnome-mdi-child.h>
#include <libgnomeui/gnome-mdi-generic-child.h>
#include <libgnomeui/gnome-mdi-session.h>
#include <libgnomeui/gnome-vfs-util.h>
#include <libgnomeui/gnome-pixmap.h>
#include <libgnomeui/gnome-pixmap-entry.h>
#include <libgnomeui/gnome-popup-menu.h>
#include <libgnomeui/gnome-propertybox.h>

#endif

==> libgnomeui-2.3.0.tar.bz2: libgnomeui-2.3.0/libgnomeui/libgnomeui.h <==
/*  -*- Mode: C; c-set-style: linux; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
/*
 * Copyright (C) 1997, 1998, 1999, 2000 Free Software Foundation
 * All rights reserved.
 *
 * This file is part of the Gnome Library.
 *
 * The Gnome Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * The Gnome Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with the Gnome Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
/*
  @NOTATION@
 */

#ifndef LIBGNOMEUI_H
#define LIBGNOMEUI_H


#include <libgnomeui/gnome-uidefs.h>

#include <libgnomeui/gnome-about.h>
#include <libgnomeui/gnome-app.h>
#include <libgnomeui/gnome-app-helper.h>
#include <libgnomeui/gnome-app-util.h>
#include <libgnomeui/gnome-appbar.h>
#include <libgnomecanvas/gnome-canvas.h>
#include <libgnomecanvas/gnome-canvas-pixbuf.h>
#include <libgnomecanvas/gnome-canvas-line.h>
#include <libgnomecanvas/gnome-canvas-rect-ellipse.h>
#include <libgnomecanvas/gnome-canvas-polygon.h>
#include <libgnomecanvas/gnome-canvas-text.h>
#include <libgnomecanvas/gnome-canvas-util.h>
#include <libgnomecanvas/gnome-canvas-widget.h>
#include <libgnomeui/gnome-color-picker.h>
#include <libgnomeui/gnome-entry.h>
#include <libgnomeui/gnome-file-entry.h>
#include <libgnomeui/gnome-font-picker.h>
#include <libgnomeui/gnome-icon-entry.h>
#include <libgnomeui/gnome-icon-item.h>
#include <libgnomeui/gnome-icon-list.h>
#include <libgnomeui/gnome-icon-sel.h>
#include <libgnomeui/gnome-ui-init.h>
#include <libgnomeui/gnome-types.h>
#include <libgnomeui/gnome-icon-theme.h>
#include <libgnomeui/gnome-thumbnail.h>
#include <libgnomeui/gnome-icon-lookup.h>
#include <libgnomeui/gnome-stock-icons.h>
#include <libgnomeui/gnome-scores.h>
#include <libgnomeui/gnome-client.h>
#include <libgnomeui/gnome-dateedit.h>
#include <libgnomeui/gnometypebuiltins.h>
#include <libgnomeui/gnome-href.h>
#include <libgnomeui/gnome-dialog.h>
#include <libgnomeui/gnome-dialog-util.h>
#include <libgnomeui/gnome-druid.h>
#include <libgnomeui/gnome-druid-page.h>
#include <libgnomeui/gnome-druid-page-edge.h>
#include <libgnomeui/gnome-druid-page-standard.h>
#include <libgnomeui/gnome-messagebox.h>
#include <libgnomeui/gnome-mdi.h>
#include <libgnomeui/gnome-mdi-child.h>
#include <libgnomeui/gnome-mdi-generic-child.h>
#include <libgnomeui/gnome-mdi-session.h>
#include <libgnomeui/gnome-vfs-util.h>
#include <libgnomeui/gnome-pixmap.h>
#include <libgnomeui/gnome-pixmap-entry.h>
#include <libgnomeui/gnome-popup-menu.h>
#include <libgnomeui/gnome-propertybox.h>
#include <libgnomeui/gnome-window-icon.h>

#endif
